@@ -12,7 +12,7 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-import mock
+from unittest import mock
 
 from zun.common import consts
 from zun.common import exception
@@ -38,7 +38,7 @@ class TestAPI(base.TestCase):
         self.compute_api = api.API(self.context)
         self.container = objects.Container(
             self.context, **utils.get_test_container())
-        self.network = objects.Network(
+        self.network = objects.ZunNetwork(
             self.context, **utils.get_test_network())
 
     @mock.patch('zun.compute.api.API._record_action_start')
@@ -59,7 +59,7 @@ class TestAPI(base.TestCase):
                                                 'limits': {}}
         mock_image_search.return_value = [image_meta]
         self.compute_api.container_create(self.context, container,
-                                          None, None, None, False)
+                                          {}, None, None, False)
         self.assertTrue(mock_schedule_container.called)
         self.assertTrue(mock_image_search.called)
         self.assertTrue(mock_container_create.called)
@@ -81,7 +81,7 @@ class TestAPI(base.TestCase):
         mock_image_search.side_effect = exception.OperationNotSupported
 
         self.compute_api.container_create(self.context, container,
-                                          None, None, None, False)
+                                          {}, None, None, False)
         self.assertTrue(mock_schedule_container.called)
         self.assertTrue(mock_image_search.called)
         self.assertTrue(mock_container_create.called)
@@ -95,7 +95,7 @@ class TestAPI(base.TestCase):
         mock_schedule_container.side_effect = exception.NoValidHost(
             reason='not enough host')
         self.compute_api.container_create(self.context, container,
-                                          None, None, None, False)
+                                          {}, None, None, False)
         self.assertTrue(mock_schedule_container.called)
         self.assertTrue(mock_save.called)
         self.assertEqual(consts.ERROR, container.status)
@@ -118,7 +118,7 @@ class TestAPI(base.TestCase):
         mock_image_search.side_effect = exception.ZunException
 
         self.compute_api.container_create(
-            self.context, container, None, None, None, False)
+            self.context, container, {}, None, None, False)
         self.assertTrue(mock_schedule_container.called)
         self.assertTrue(mock_image_search.called)
         self.assertFalse(mock_save.called)
